@@ -7,7 +7,19 @@ use base qw( Module::Build );
 sub new
 {
   my($class, %args) = @_;
-  $args{requires}->{'EV'} = 0 if $^O eq 'MSWin32';
+  
+  if($^O eq 'MSWin32')
+  {
+    if(eval q{ use 5.020; 1 })
+    {
+      $args{requires}->{Event} = 0;
+    }
+    else
+    {
+      $args{requires}->{EV} = 0;
+    }
+  }
+  
   my $self = $class->SUPER::new(%args);
   $self;
 }
